# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: EddytorGRPC.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'EddytorGRPC.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x45\x64\x64ytorGRPC.proto\x12\x0c\x45\x64\x64ytor_grpc\"\x07\n\x05\x45mpty\"\xa7\x02\n\x0cQueryMessage\x12:\n\x0ftable_reference\x18\x01 \x01(\x0b\x32!.Eddytor_grpc.ProtoTableReference\x12\x12\n\x05limit\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x03 \x01(\x04H\x01\x88\x01\x01\x12+\n\x07\x66ilters\x18\x04 \x03(\x0b\x32\x1a.Eddytor_grpc.ColumnFilter\x12\x18\n\x0bsearch_text\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x16\n\x0esearch_columns\x18\x06 \x03(\t\x12.\n\x0csort_columns\x18\x07 \x03(\x0b\x32\x18.Eddytor_grpc.SortColumnB\x08\n\x06_limitB\t\n\x07_offsetB\x0e\n\x0c_search_text\"0\n\nSortColumn\x12\x0e\n\x06\x63olumn\x18\x01 \x01(\t\x12\x12\n\ndescending\x18\x02 \x01(\x08\"@\n\x0c\x43olumnFilter\x12\x0e\n\x06\x63olumn\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"E\n\x13ProtoTableReference\x12\x0f\n\x07\x63\x61talog\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\r\n\x05table\x18\x03 \x01(\t\"P\n\x10\x41rrowRecordBatch\x12\x14\n\x0crecord_batch\x18\x01 \x01(\x0c\x12\x17\n\ntotal_rows\x18\x02 \x01(\x04H\x00\x88\x01\x01\x42\r\n\x0b_total_rows\"d\n\x10TableRecordBatch\x12:\n\x0ftable_reference\x18\x01 \x01(\x0b\x32!.Eddytor_grpc.ProtoTableReference\x12\x14\n\x0crecord_batch\x18\x02 \x01(\x0c\"\x85\x01\n\x0fMergeRpcRequest\x12:\n\x0ftable_reference\x18\x01 \x01(\x0b\x32!.Eddytor_grpc.ProtoTableReference\x12\x14\n\x07\x63omment\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x0crecord_batch\x18\x03 \x01(\x0c\x42\n\n\x08_comment\"\x93\x01\n\x13\x41\x64\x64\x43olumnRpcRequest\x12:\n\x0ftable_reference\x18\x01 \x01(\x0b\x32!.Eddytor_grpc.ProtoTableReference\x12\x0e\n\x06schema\x18\x02 \x01(\x0c\x12\x30\n\x0b\x63onstraints\x18\x03 \x03(\x0b\x32\x1b.Eddytor_grpc.RpcConstraint\"+\n\rRpcConstraint\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x65xpr\x18\x02 \x01(\t\"\xb2\x01\n\x15\x43reateTableRpcRequest\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\x0c\x12\x30\n\x0b\x63onstraints\x18\x03 \x03(\x0b\x32\x1b.Eddytor_grpc.RpcConstraint\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0f\n\x07\x63omment\x18\x05 \x01(\t\x12 \n\x18override_table_on_insert\x18\x06 \x01(\x08\"h\n\x13\x43reateTableResponse\x12:\n\x0ftable_reference\x18\x01 \x01(\x0b\x32!.Eddytor_grpc.ProtoTableReference\x12\x15\n\rrows_inserted\x18\x02 \x01(\x04\x32\xce\x03\n\x0b\x45\x64\x64ytorGRPC\x12J\n\nStreamData\x12\x1a.Eddytor_grpc.QueryMessage\x1a\x1e.Eddytor_grpc.ArrowRecordBatch0\x01\x12\x46\n\x0fInsertIntoTable\x12\x1e.Eddytor_grpc.TableRecordBatch\x1a\x13.Eddytor_grpc.Empty\x12@\n\nMergeTable\x12\x1d.Eddytor_grpc.MergeRpcRequest\x1a\x13.Eddytor_grpc.Empty\x12\x46\n\x0f\x44\x65leteFromTable\x12\x1e.Eddytor_grpc.TableRecordBatch\x1a\x13.Eddytor_grpc.Empty\x12J\n\x10\x41\x64\x64\x43olumnToTable\x12!.Eddytor_grpc.AddColumnRpcRequest\x1a\x13.Eddytor_grpc.Empty\x12U\n\x0b\x43reateTable\x12#.Eddytor_grpc.CreateTableRpcRequest\x1a!.Eddytor_grpc.CreateTableResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'EddytorGRPC_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EMPTY']._serialized_start=35
  _globals['_EMPTY']._serialized_end=42
  _globals['_QUERYMESSAGE']._serialized_start=45
  _globals['_QUERYMESSAGE']._serialized_end=340
  _globals['_SORTCOLUMN']._serialized_start=342
  _globals['_SORTCOLUMN']._serialized_end=390
  _globals['_COLUMNFILTER']._serialized_start=392
  _globals['_COLUMNFILTER']._serialized_end=456
  _globals['_PROTOTABLEREFERENCE']._serialized_start=458
  _globals['_PROTOTABLEREFERENCE']._serialized_end=527
  _globals['_ARROWRECORDBATCH']._serialized_start=529
  _globals['_ARROWRECORDBATCH']._serialized_end=609
  _globals['_TABLERECORDBATCH']._serialized_start=611
  _globals['_TABLERECORDBATCH']._serialized_end=711
  _globals['_MERGERPCREQUEST']._serialized_start=714
  _globals['_MERGERPCREQUEST']._serialized_end=847
  _globals['_ADDCOLUMNRPCREQUEST']._serialized_start=850
  _globals['_ADDCOLUMNRPCREQUEST']._serialized_end=997
  _globals['_RPCCONSTRAINT']._serialized_start=999
  _globals['_RPCCONSTRAINT']._serialized_end=1042
  _globals['_CREATETABLERPCREQUEST']._serialized_start=1045
  _globals['_CREATETABLERPCREQUEST']._serialized_end=1223
  _globals['_CREATETABLERESPONSE']._serialized_start=1225
  _globals['_CREATETABLERESPONSE']._serialized_end=1329
  _globals['_EDDYTORGRPC']._serialized_start=1332
  _globals['_EDDYTORGRPC']._serialized_end=1794
# @@protoc_insertion_point(module_scope)
